<template>
    <div class="monitor-dialog">
        <div :class="['popup-volumn', {orange: volumnInfo.sourceData >= 50}]">
            音量

            <template v-if="volumnInfo.sourceData">
                <span
                    class="volumn-num"
                    v-for="(item, index) in String(volumnInfo.sourceData).split(
                        ''
                    )"
                    :key="index"
                >
                    {{ item }}
                </span>
            </template>
            <span v-else class="volumn-num">-</span>
            dB
        </div>
        <!-- 设备信息 -->
        <div class="device-info">
            <div class="device-item">
                <div class="label">设备编码：</div>
                <div class="value">{{ volumnInfo.code }}</div>
            </div>
            <div class="device-item">
                <div class="label">设备名称：</div>
                <div class="value">{{ volumnInfo.name }}</div>
            </div>
            <div class="device-item">
                <div class="label">经度：</div>
                <div class="value">{{ volumnInfo.lgtd }}</div>
            </div>
            <div class="device-item">
                <div class="label">纬度：</div>
                <div class="value">{{ volumnInfo.lttd }}</div>
            </div>
            <div class="warning-item" style="width: 100%">
                <div class="table-info">
                    <div class="header">
                        <div class="header-item" style="width: 7%">序号</div>
                        <div class="header-item" style="width: 20%">
                            事件名称
                        </div>
                        <div class="header-item" style="width: 12%">
                            告警等级
                        </div>
                        <div class="header-item" style="width: 25%">
                            告警内容
                        </div>
                        <div class="header-item" style="width: 21%">
                            发生日期
                        </div>
                        <div class="header-item" style="width: 15%">
                            事件状态
                        </div>
                        <!-- <div class="header-item" style="width: 13%">
                            预警图片
                        </div>
                        <div class="header-item" style="width: 15%">操作</div> -->
                    </div>
                    <div class="body-content">
                        <div
                            class="body"
                            v-for="(item, index) in tableData"
                            :key="index"
                        >
                            <div class="body-item" style="width: 7%">
                                {{
                                    index +
                                    (pageParams.page - 1) *
                                        pageParams.pageSize +
                                    1
                                }}
                            </div>
                            <div class="body-item" style="width: 20%">
                                {{ item.eventName }}
                            </div>
                            <div class="body-item" style="width: 12%">
                                {{ getDictName('gjdj', item.eventLevel) }}
                            </div>
                            <div class="body-item" style="width: 25%">
                                {{ item.memo }}
                            </div>
                            <div class="body-item" style="width: 21%">
                                {{ item.eventProduceTime }}
                            </div>
                            <div class="body-item operate" style="width: 15%">
                                <el-tag
                                    size="mini"
                                    @click="goSystem(item)"
                                    effect="dark"
                                    >未处置</el-tag
                                >
                            </div>
                            <!-- <div class="body-item operate" style="width: 13%">
                                <el-tag
                                    size="mini"
                                    @click="openImg(item)"
                                    type="warning"
                                    effect="dark"
                                    >查看</el-tag
                                >
                            </div> -->
                            <!-- <div class="body-item operate" style="width: 15%">
                                <el-tag
                                    size="mini"
                                    @click="goSystem"
                                    effect="dark"
                                    >处理</el-tag
                                >
                            </div> -->
                        </div>
                    </div>
                    <el-pagination
                        style="float: right; margin-top: 6px"
                        :current-page="pageParams.page"
                        :page-size="pageParams.pageSize"
                        @current-change="handleCurrentChange"
                        layout="total, prev, pager, next, jumper"
                        :total="total"
                    >
                    </el-pagination>
                </div>
                <el-image
                    ref="warningImg"
                    style="width: 100px; height: 100px"
                    :src="url"
                    :preview-src-list="srcList"
                    v-show="false"
                >
                </el-image>
            </div>
        </div>
        <!-- 预警信息 -->
    </div>
</template>

<script>
import player from '../player.vue'
import bigScreenAPI from '@/api/BigScreen/index.js'
import utils from '@/utils.js'
export default {
    name: 'volumnDialog',
    components: {
        player,
    },
    props: {
        volumnInfo: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    watch: {},
    data() {
        return {
            tableData: [], // 预警数据
            url: '',
            srcList: [],
            pageParams: {
                page: 1,
                pageSize: 8,
            }, // 分页参数
            total: 0, // 总数
        }
    },
    created() {},
    methods: {
        // 获取预警信息
        getWarningList() {
            bigScreenAPI
                .queryWarningListByCode({
                    groupRelation: 'AND',
                    groupTree: {},
                    pageBean: {
                        showTotal: true,
                        ...this.pageParams
                    },
                    params: {},
                    querys: [
                        {
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'device_code_',
                            relation: 'AND',
                            value: this.volumnInfo.code,
                        },
                    ],
                })
                .then((res) => {
                    console.log(res)
                    this.tableData = res.rows
                    this.total = res.total
                })
        },
        // 跳转后台
        goSystem(item) {
            // this.$router.push({path: `/platLayout/${this.workPlatMenu[0].children[0].children[1].alias}`,})
            // this.$router.push({path: `/platLayout/BlacklistManage`})
            this.$emit('eventConfirmation', item,'智能检测')
        },
        // 获取字典值翻译
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        // 打开预警图片
        openImg(item) {
            // console.log(this.$refs.warningImg);
            if (item.imgUrl) {
                bigScreenAPI.getImgByUrl(item.imgUrl).then((res) => {
                    this.srcList = res
                    this.$refs.warningImg.clickHandler()
                })
            } else {
                this.$message({
                    message: '暂无图片！',
                    type: 'warning',
                })
            }
        },
        // 翻页
        handleCurrentChange(val) {
            this.pageParams.page = val
            this.getWarningList()
        },
    },
}
</script>

<style scoped lang="scss">
.monitor-dialog {
    // width: 600px;
    // height: 520px;
    height: 450px;
}
.warning-item {
    padding: 15px 0 0 0;
    // border: 1px solid #fff;
    .table-info {
        border: 1px solid #42bddc;
        .header {
            display: flex;
            height: 35px;
            background: linear-gradient(
                360deg,
                #1a355c 0%,
                rgba(66, 93, 133, 0.09) 100%
            );
            .header-item {
                color: #fff;
                display: flex;
                align-items: center;
                justify-content: center;
                padding: 0 0 0 6px;
                font-size: 16px;
            }
        }
        .body-content {
            height: 245px;
            overflow-y: auto;
            .body {
                display: flex;
                // height: 25px;
                border-right: none;
                border: 2px solid transparent;
                padding: 3px 0;

                &:hover {
                    background: linear-gradient(
                        90deg,
                        rgba(16, 40, 73, 0) 0%,
                        #102849 51%,
                        rgba(16, 40, 73, 0) 100%
                    );
                    border-radius: 0px 0px 0px 0px;
                    border: 2px solid;
                    border-image: linear-gradient(
                            90deg,
                            rgba(255, 255, 255, 0),
                            rgba(93, 144, 194, 1),
                            rgba(93, 144, 194, 0)
                        )
                        2 2;
                }
                .body-item {
                    color: #eee;
                    display: flex;
                    align-items: center;
                    justify-content: center;
                    padding: 0 0 0 6px;
                }
                .operate {
                    span {
                        cursor: pointer;
                        // &:hover {
                        //     color: #1a8cff;
                        // }
                    }
                }
            }
        }
    }
}
.device-info {
    height: 400px;
    padding: 8px 0 0 0;
    display: flex;
    flex-wrap: wrap;
    align-content: flex-start;
    .device-item {
        width: 50%;
        margin: 10px 0 0 0;
        display: flex;
        .label {
            color: #2ca6ff;
        }
        .value {
            color: #fff;
        }
    }
}
.popup-volumn {
    font-weight: 400;
    color: #ffffff;
    font-size: 16px;
    text-align: center;
    border-bottom: 1px solid #5a9bb2;
    padding: 20px 0;
    // margin-bottom: 20px;
    .volumn-num {
        display: inline-block;
        width: 26px;
        height: 36px;
        line-height: 36px;
        background: #1a8cff;
        border-radius: 4px 4px 4px 4px;
        font-size: 30px;
        color: #e5f2ff;
    }
    .volumn-num ~ .volumn-num {
        margin-left: 4px;
    }
}
.popup-volumn.orange {
    border-bottom: 1px solid #2a3c57;
    .volumn-num {
        background: #ff973f;
    }
}
</style>
